
/* Chrysalide - Outil d'analyse de fichiers binaires
 * matches.h - prototypes pour la sauvegarde de correspondances de motif identifiées
 *
 * Copyright (C) 2022 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _ANALYSIS_SCAN_MATCHES_H
#define _ANALYSIS_SCAN_MATCHES_H


#include <glib-object.h>


#include "pattern.h"
#include "../../common/szstr.h"



#define G_TYPE_SCAN_MATCHES            g_scan_matches_get_type()
#define G_SCAN_MATCHES(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), G_TYPE_SCAN_MATCHES, GScanMatches))
#define G_IS_SCAN_MATCHES(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), G_TYPE_SCAN_MATCHES))
#define G_SCAN_MATCHES_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), G_TYPE_SCAN_MATCHES, GScanMatchesClass))
#define G_IS_SCAN_MATCHES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), G_TYPE_SCAN_MATCHES))
#define G_SCAN_MATCHES_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), G_TYPE_SCAN_MATCHES, GScanMatchesClass))


/* Correspondances trouvées avec un motif (instance) */
typedef struct _GScanMatches GScanMatches;

/* Correspondances trouvées avec un motif (classe) */
typedef struct _GScanMatchesClass GScanMatchesClass;


/* Indique le type défini pour une série de correspondances identifiées. */
GType g_scan_matches_get_type(void);

/* Associe des éléments de contexte à des correspondances. */
void g_scan_matches_attach(GScanMatches *, const GScanContext *, const GSearchPattern *);

/* Fournit le contexte du scan associé aux correspondances. */
GScanContext *g_scan_bytes_matches_get_context(const GScanMatches *);

/* Indique la source du motif d'origine recherché. */
GSearchPattern *g_scan_matches_get_source(const GScanMatches *);

/* Dénombre les correspondances enregistrées pour un motif. */
size_t g_scan_matches_count(const GScanMatches *);

/* Affiche une série de correspondances au format texte. */
void g_scan_matches_output_to_text(const GScanMatches *, int);

/* Convertit une série de correspondances en texte. */
void g_scan_matches_convert_as_text(const GScanMatches *);

/* Affiche une série de correspondances au format JSON. */
void g_scan_matches_output_to_json(const GScanMatches *, const sized_string_t *, unsigned int, int);

/* Convertit une série de correspondances en JSON. */
void g_scan_matches_convert_as_json(const GScanMatches *);



#endif  /* _ANALYSIS_SCAN_MATCHES_H */
